sqlobject.joins module — SQLObject 3.9.1 documentation

# sqlobject.joins module

class `sqlobject.joins.` `ManyToMany`(*args, **kw)

  Bases: `sqlobject.boundattributes.BoundFactory`

  `createJoinTable` = True
  `declarative_count` = 3
  `factory_class`

    alias of `sqlobject.joins.SOManyToMany`

  `intermediateTable` = None
  `joinColumn` = None
  `otherColumn` = None

class `sqlobject.joins.` `MultipleJoin`(otherClass=None, **kw)

  Bases: `sqlobject.joins.Join`

  `baseClass`

    alias of `sqlobject.joins.SOMultipleJoin`

class `sqlobject.joins.` `OneToMany`(*args, **kw)

  Bases: `sqlobject.boundattributes.BoundFactory`

  `declarative_count` = 4
  `factory_class`

    alias of `sqlobject.joins.SOOneToMany`

  `joinColumn` = None

class `sqlobject.joins.` `RelatedJoin`(otherClass=None, **kw)

  Bases: `sqlobject.joins.MultipleJoin`

  `baseClass`

    alias of `sqlobject.joins.SORelatedJoin`

class `sqlobject.joins.` `SQLMultipleJoin`(otherClass=None, **kw)

  Bases: `sqlobject.joins.Join`

  `baseClass`

    alias of `sqlobject.joins.SOSQLMultipleJoin`

class `sqlobject.joins.` `SQLRelatedJoin`(otherClass=None, **kw)

  Bases: `sqlobject.joins.RelatedJoin`

  `baseClass`

    alias of `sqlobject.joins.SOSQLRelatedJoin`

class `sqlobject.joins.` `SingleJoin`(otherClass=None, **kw)

  Bases: `sqlobject.joins.Join`

  `baseClass`

    alias of `sqlobject.joins.SOSingleJoin`